import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import PropTypes from 'prop-types';
import React, { useRef, useContext } from 'react';
import AdvertisingContext from '../AdvertisingContext';
import isLazyLoading from './utils/isLazyLoading';
import getLazyLoadConfig from './utils/getLazyLoadConfig';
import { useIsomorphicLayoutEffect } from '../hooks/useIsomorphicLayoutEffect';
import { useIntersectionObserver } from '../hooks/useIntersectionObserver';

function AdvertisingSlot(_ref) {
  var id = _ref.id,
      style = _ref.style,
      className = _ref.className,
      children = _ref.children,
      customEventHandlers = _ref.customEventHandlers,
      _ref$onAdLoaded = _ref.onAdLoaded,
      onAdLoaded = _ref$onAdLoaded === void 0 ? function () {} : _ref$onAdLoaded,
      restProps = _objectWithoutProperties(_ref, ["id", "style", "className", "children", "customEventHandlers", "onAdLoaded"]);

  var containerDivRef = useRef();

  var _useContext = useContext(AdvertisingContext),
      activate = _useContext.activate,
      config = _useContext.config;

  var lazyLoadConfig = getLazyLoadConfig(config, id);
  var isLazyLoadEnabled = isLazyLoading(lazyLoadConfig);
  useIntersectionObserver(activate, config, id, customEventHandlers, onAdLoaded, containerDivRef, isLazyLoadEnabled);
  useIsomorphicLayoutEffect(function () {
    if (!config || isLazyLoadEnabled) {
      return;
    }

    activate(id, customEventHandlers, onAdLoaded);
  }, [activate, config]);
  return /*#__PURE__*/React.createElement("div", _extends({
    id: id,
    style: style,
    className: className,
    children: children,
    ref: containerDivRef
  }, restProps));
}

AdvertisingSlot.propTypes = {
  id: PropTypes.string.isRequired,
  style: PropTypes.object,
  className: PropTypes.string,
  children: PropTypes.node,
  customEventHandlers: PropTypes.objectOf(PropTypes.func).isRequired,
  onAdLoaded: PropTypes.func
};
AdvertisingSlot.defaultProps = {
  customEventHandlers: {},
  onAdLoaded: function onAdLoaded() {}
};
export default AdvertisingSlot;